@@ -373,6 +373,7 @@ void App_Glom::init_menus()
     "        <menuitem action='GlomAction_Menu_Developer_Database_Preferences' />"
     "        <menuitem action='GlomAction_Menu_Developer_Fields' />"
     "        <menuitem action='GlomAction_Menu_Developer_Relationships' />"
+    "        <menuitem action='GlomAction_Menu_Developer_RelationshipsOverview' />"
     "        <menuitem action='GlomAction_Menu_Developer_Layout' />"
     "        <menuitem action='GlomAction_Menu_Developer_Users' />"
     "        <menuitem action='GlomAction_Menu_Developer_Reports' />"
@@ -445,8 +446,8 @@ Glib::ustring App_Glom::get_file_uri_without_extension(const Glib::ustring& uri)
     const Glib::ustring filename_part_without_ext = filename_part.substr(0, pos_dot);
     const Glib::ustring uri_parent = vfs_uri->extract_dirname();
 
-    Glib::RefPtr<Gnome::Vfs::Uri> vfs_uri_without_extension = Gnome::Vfs::Uri::create(uri_parent);
-    vfs_uri_without_extension->append_string(filename_part_without_ext);
+    Glib::RefPtr<Gnome::Vfs::Uri> vfs_uri_parent = Gnome::Vfs::Uri::create(uri_parent);
+    Glib::RefPtr<Gnome::Vfs::Uri> vfs_uri_without_extension = vfs_uri_parent->append_string(filename_part_without_ext);
 
     return vfs_uri_without_extension->to_string();
   }
@@ -758,7 +759,9 @@ bool App_Glom::on_document_load()
 
           if(!is_example) /* It will be started later, after we have asked for the initial db name/title and created the files.*/
           {
-            connection_pool->start_self_hosting(); //Stopped in on_menu_file_close().
+            const bool test = connection_pool->start_self_hosting(); //Stopped in on_menu_file_close().
+            if(!test)
+              return false;
           }
         }
         else
@@ -958,6 +961,9 @@ bool App_Glom::offer_new_or_existing()
     //This will use an extended save dialog that also asks for the database title and some hosting details:
     Glib::ustring db_title;
 
+    m_ui_save_extra_showextras = true; //Offer self-hosting or central hosting, and offer the database title.
+    m_ui_save_extra_newdb_title.clear();
+    m_ui_save_extra_newdb_selfhosted = true; /* Default to self-hosting */
     offer_saveas();
 
     //Check that the document was given a location:
