@@ -21,6 +21,9 @@
 #include "box_data_list_find.h"
 #include <glibmm/i18n.h>
 
+namespace Glom
+{
+
 Box_Data_List_Find::Box_Data_List_Find()
 : m_HBox(false, 6)
 {
@@ -47,9 +50,9 @@ bool Box_Data_List_Find::fill_from_database()
 {
   Bakery::BusyCursor busy_cursor(get_app_window());
 
-  bool result = Box_DB_Table::fill_from_database();
-
-  m_AddDel.remove_all();
+  const bool result = Box_DB_Table::fill_from_database();
+  if(!result)
+    return false;
 
   //Field Names:
   create_layout();
@@ -88,3 +91,5 @@ bool Box_Data_List_Find::init_db_details(const Glib::ustring& table_name)
   found_set.m_table_name = table_name;
   return Box_Data_List::init_db_details(found_set);
 }
+
+} //namespace Glom
